@@ -15,6 +15,8 @@
 
 """Volume interface (v2 extension)."""
 
+import warnings
+
 from cinderclient.apiclient import base as common_base
 from cinderclient import base
 
@@ -33,7 +35,17 @@ class Volume(base.Resource):
         return self.manager.update(self, **kwargs)
 
     def attach(self, instance_uuid, mountpoint, mode='rw', host_name=None):
-        """Set attachment metadata.
+        """Inform Cinder that the given volume is attached to the given instance.
+
+        Calling this method will not actually ask Cinder to attach
+        a volume, but to mark it on the DB as attached. If the volume
+        is not actually attached to the given instance, inconsistent
+        data will result.
+
+        The right flow of calls is :
+        1- call reserve
+        2- call initialize_connection
+        3- call attach
 
         :param instance_uuid: uuid of the attaching instance.
         :param mountpoint: mountpoint on the attaching instance or host.
@@ -44,7 +56,18 @@ class Volume(base.Resource):
                                    host_name)
 
     def detach(self):
-        """Clear attachment metadata."""
+        """Inform Cinder that the given volume is detached from the given instance.
+
+        Calling this method will not actually ask Cinder to detach
+        a volume, but to mark it on the DB as detached. If the volume
+        is not actually detached from the given instance, inconsistent
+        data will result.
+
+        The right flow of calls is :
+        1- call reserve
+        2- call initialize_connection
+        3- call detach
+        """
         return self.manager.detach(self)
 
     def reserve(self, volume):
@@ -113,6 +136,7 @@ class Volume(base.Resource):
                         disk_format, visibility=None,
                         protected=None):
         """Upload a volume to image service as an image.
+
         :param force: Boolean to enables or disables upload of a volume that
                       is attached to an instance.
         :param image_name: The new image name.
@@ -237,7 +261,7 @@ class VolumeManager(base.ManagerWithFind):
         :param scheduler_hints: (optional extension) arbitrary key-value pairs
                             specified by the client to help boot an instance
         :param multiattach: Allow the volume to be attached to more than
-                            one instance
+                            one instance (deprecated)
         :rtype: :class:`Volume`
         """
         if metadata is None:
@@ -245,6 +269,13 @@ class VolumeManager(base.ManagerWithFind):
         else:
             volume_metadata = metadata
 
+        if multiattach:
+            warnings.warn('The ``multiattach`` volume create flag is '
+                          'deprecated and will be removed in a future '
+                          'release. Multiattach capability is now controlled '
+                          'using volume type extra specs.',
+                          DeprecationWarning)
+
         body = {'volume': {'size': size,
                            'consistencygroup_id': consistencygroup_id,
                            'snapshot_id': snapshot_id,
